
package com.navigine.navigine;

import android.content.Context;
import android.util.Log;

import com.navigine.naviginesdk.DeviceInfo;
import com.navigine.naviginesdk.Location;
import com.navigine.naviginesdk.NavigationThread;
import com.navigine.naviginesdk.NavigineSDK;

import java.util.Locale;

import io.flutter.plugin.common.MethodChannel;

class NavigineHelper {
    private final MethodChannel methodChannel;
    NavigationThread navigation;


    NavigineHelper(MethodChannel methodChannel) {
        this.methodChannel = methodChannel;
    }

    boolean initializeSDK(Context context, String userHash, String serverUrl) {
        return NavigineSDK.initialize(context, userHash, serverUrl);
    }

    void loadLocation(int locationId) {
        NavigineSDK.loadLocationInBackground(locationId, new Location.LoadListener() {
            @Override
            public void onUpdate(int state) {
                super.onUpdate(state);
                methodChannel.invokeMethod("location#onUpdate", state);
            }

            @Override
            public void onFailed(int error) {
                super.onFailed(error);
                methodChannel.invokeMethod("location#onFailed", error);
            }

            @Override
            public void onFinished() {
                super.onFinished();
                methodChannel.invokeMethod("location#onFinished", null);
            }
        });
    }

    void getDeviceInfoStream(){
        navigation.setDeviceListener(new DeviceInfo.Listener(){
            @Override
            public void onUpdate(DeviceInfo info) {
                super.onUpdate(info);
                methodChannel.invokeMethod("deviceInfo#onUpdate",Convert.deviceInfoToObject(navigation.getDeviceInfo()));
            }
        });
    }

    void startNavigation(int mode) {
        navigation = NavigineSDK.getNavigation();
        if (navigation == null)
            return;
        navigation.setMode(mode);
    }

    Object getDeviceInfo() {
        return Convert.deviceInfoToObject(navigation.getDeviceInfo());
    }

    Object getLocation() {
        return Convert.locationToObject(navigation.getLocation());
    }

    void stopNavigation() {
        NavigineSDK.finish();
    }
}
